#include "geo_incode_defs.h"
datafile_rows_t prime_meridian_row_0[] = {"PRIME_MERIDIAN_CODE","PRIME_MERIDIAN_NAME","GREENWICH_LONGITUDE","UOM_CODE","REMARKS","INFORMATION_SOURCE","DATA_SOURCE","REVISION_DATE","CHANGE_ID","DEPRECATED ",NULL};
datafile_rows_t prime_meridian_row_1[] = {"8901","Greenwich","0.0","9110","","","EPSG","1995-06-02 00:00:00","96.29","0 ",NULL};
datafile_rows_t prime_meridian_row_2[] = {"8902","Lisbon","-9.0754862","9110","","Instituto Geografico e Cadastral; Lisbon","EPSG","1995-06-02 00:00:00","96.29","0 ",NULL};
datafile_rows_t prime_meridian_row_3[] = {"8903","Paris","2.5969213","9105","Value adopted by IGN (Paris) in 1936. Equivalent to 2 deg 20min 14.025sec. Preferred by EPSG to earlier value of 2deg 20min 13.95sec (2.596898 grads) used by RGS London.","Institut Geographique National (IGN); Paris","EPSG","1995-06-02 00:00:00","","0 ",NULL};
datafile_rows_t prime_meridian_row_4[] = {"8904","Bogota","-74.04513","9110","","Instituto Geografico \"Augustin Cadazzi\" (IGAC); Bogota","EPSG","1995-06-02 00:00:00","96.29","0 ",NULL};
datafile_rows_t prime_meridian_row_5[] = {"8905","Madrid","-3.411658","9110","","","EPSG","1995-06-02 00:00:00","96.29","0 ",NULL};
datafile_rows_t prime_meridian_row_6[] = {"8906","Rome","12.27084","9110","","","EPSG","1995-06-02 00:00:00","96.29","0 ",NULL};
datafile_rows_t prime_meridian_row_7[] = {"8907","Bern","7.26225","9110","1895 value.  Newer value of 7 deg 26 min 22.335 sec E determined in 1938.","Bundesamt für Landestopographie","EPSG","1995-06-02 00:00:00","96.29","0 ",NULL};
datafile_rows_t prime_meridian_row_8[] = {"8908","Jakarta","106.482779","9110","","","EPSG","1995-06-02 00:00:00","96.29","0 ",NULL};
datafile_rows_t prime_meridian_row_9[] = {"8909","Ferro","-17.4","9110","Used in Austria and former Czechoslovakia.","","EPSG","1995-06-02 00:00:00","96.29","0 ",NULL};
datafile_rows_t prime_meridian_row_10[] = {"8910","Brussels","4.220471","9110","","","EPSG","1995-06-02 00:00:00","96.29","0 ",NULL};
datafile_rows_t prime_meridian_row_11[] = {"8911","Stockholm","18.03298","9110","","","EPSG","1995-06-02 00:00:00","96.29","0 ",NULL};
datafile_rows_t prime_meridian_row_12[] = {"8912","Athens","23.4258815","9110","Used in Greece for older mapping based on Hatt projection.","Topography Department; National Technical University of Athens.","EPSG","1997-06-16 00:00:00","","0 ",NULL};
datafile_rows_t prime_meridian_row_13[] = {"8913","Oslo","10.43225","9110","Formerly known as Kristiania or Christiania.","Statens Kartverk - Geodesidivisjonen","EPSG","1999-10-20 00:00:00","","0 ",NULL};
datafile_rows_t *prime_meridian_rows[] = {prime_meridian_row_0 ,prime_meridian_row_1 ,prime_meridian_row_2 ,prime_meridian_row_3 ,prime_meridian_row_4 ,prime_meridian_row_5 ,prime_meridian_row_6 ,prime_meridian_row_7 ,prime_meridian_row_8 ,prime_meridian_row_9 ,prime_meridian_row_10 ,prime_meridian_row_11 ,prime_meridian_row_12 ,prime_meridian_row_13,NULL};
