#include "geo_incode_defs.h"
datafile_rows_t unit_of_measure_row_0[] = {"uom_code","unit_of_meas_name","unit_of_meas_type","target_uom_code","factor_b","factor_c","remarks","information_source","data_source","revision_date","change_id","deprecated ",NULL};
datafile_rows_t unit_of_measure_row_1[] = {"9001","metre","length","9001","1","1","Also known as International metre. SI standard unit.","ISO 1000.","EPSG","1995-06-02","","0 ",NULL};
datafile_rows_t unit_of_measure_row_2[] = {"9002","foot","length","9001","0.3048","1","","ISO 1000; 1958","EPSG","1995-06-02","","0 ",NULL};
datafile_rows_t unit_of_measure_row_3[] = {"9003","US survey foot","length","9001","12","39.37","Used in USA.","EPSG","EPSG","2000-05-07","99.99","0 ",NULL};
datafile_rows_t unit_of_measure_row_4[] = {"9005","Clarke's foot","length","9001","0.3047972654","1","Assumes Clarke's 1865 ratio of 1 British foot = 0.3047972654 French legal metres applies to the international metre.   Used in older Australian, southern African & British West Indian mapping.","Australian Land Information Group  www.auslig.gov.au","EPSG","2005-09-06","97.234 99.99  2000.05 2005.37 2005.46","0 ",NULL};
datafile_rows_t unit_of_measure_row_5[] = {"9014","fathom","length","9001","1.8288","1","= 6 feet.","","EPSG","1995-06-02","","0 ",NULL};
datafile_rows_t unit_of_measure_row_6[] = {"9030","nautical mile","length","9001","1852","1","","","EPSG","1996-10-18","96.24","0 ",NULL};
datafile_rows_t unit_of_measure_row_7[] = {"9031","German legal metre","length","9001","1.0000135965","1","Used in Namibia.","Chief Directorate Surveys and Land Information; Mowbray; South Africa","EPSG","1997-06-16","","0 ",NULL};
datafile_rows_t unit_of_measure_row_8[] = {"9033","US survey chain","length","9001","792","39.37","Used in USA primarily for public lands cadastral work.","Bureau of Land Management technical bulletin 6 (1973) and Standard Field Tables 8th edition (1956).","EPSG","2000-05-07","99.99","0 ",NULL};
datafile_rows_t unit_of_measure_row_9[] = {"9034","US survey link","length","9001","7.92","39.37","Used in USA primarily for public lands cadastral work.","Bureau of Land Management technical bulletin 6 (1973) and Standard Field Tables 8th edition (1956).","EPSG","2000-05-07","99.99","0 ",NULL};
datafile_rows_t unit_of_measure_row_10[] = {"9035","US survey mile","length","9001","63360","39.37","Used in USA primarily for public lands cadastral work.","Bureau of Land Management technical bulletin 6 (1973) and Standard Field Tables 8th edition (1956).","EPSG","2000-05-07","99.99","0 ",NULL};
datafile_rows_t unit_of_measure_row_11[] = {"9036","kilometre","length","9001","1000","1","","ISO 1000.","EPSG","1998-11-11","","0 ",NULL};
datafile_rows_t unit_of_measure_row_12[] = {"9037","Clarke's yard","length","9001","0.9143917962","1","=3 Clarke's feet.  Assumes Clarke's 1865 ratio of 1 British foot = 0.3047972654 French legal metres applies to the international metre.   Used in older Australian, southern African & British West Indian mapping.","Australian Land Information Group  www.auslig.gov.au","EPSG","2005-09-06","97.233  99.99 2005.37 2005.46","0 ",NULL};
datafile_rows_t unit_of_measure_row_13[] = {"9038","Clarke's chain","length","9001","20.1166195164","1","=22 Clarke's yards.  Assumes Clarke's 1865 ratio of 1 British foot = 0.3047972654 French legal metres applies to the international metre.   Used in older Australian, southern African & British West Indian mapping.","Australian Land Information Group  www.auslig.gov.au","EPSG","2005-09-06","97.233  99.99 2005.37 2005.46","0 ",NULL};
datafile_rows_t unit_of_measure_row_14[] = {"9039","Clarke's link","length","9001","0.201166195164","1","=1/100 Clarke's chain. Assumes Clarke's 1865 ratio of 1 British foot = 0.3047972654 French legal metres applies to the international metre.   Used in older Australian, southern African & British West Indian mapping.","Australian Land Information Group  www.auslig.gov.au","EPSG","2005-09-06","97.233  99.99 2005.37 2005.46","0 ",NULL};
datafile_rows_t unit_of_measure_row_15[] = {"9040","British yard (Sears 1922)","length","9001","36","39.370147","Uses Sear's 1922 British yard-metre ratio as given by Bomford as 39.370147 inches per metre.  Used in East Malaysian and older New Zealand mapping.","G. Bomford \"Geodesy\" 2nd edition 1962; after J.S.Clark \"Remeasurement of the Old Length Standards\"; Empire Survey Review no. 90; 1953.","EPSG","2000-05-07","97.233  99.99","0 ",NULL};
datafile_rows_t unit_of_measure_row_16[] = {"9041","British foot (Sears 1922)","length","9001","12","39.370147","Uses Sear's 1922 British yard-metre ratio as given by Bomford as 39.370147 inches per metre.  Used in East Malaysian and older New Zealand mapping.","G. Bomford \"Geodesy\" 2nd edition 1962; after J.S.Clark \"Remeasurement of the Old Length Standards\"; Empire Survey Review no. 90; 1953.","EPSG","2000-05-07","97.233  99.99","0 ",NULL};
datafile_rows_t unit_of_measure_row_17[] = {"9042","British chain (Sears 1922)","length","9001","792","39.370147","Uses Sear's 1922 British yard-metre ratio as given by Bomford as 39.370147 inches per metre.  Used in East Malaysian and older New Zealand mapping.","G. Bomford \"Geodesy\" 2nd edition 1962; after J.S.Clark \"Remeasurement of the Old Length Standards\"; Empire Survey Review no. 90; 1953.","EPSG","2000-05-07","97.233  99.99","0 ",NULL};
datafile_rows_t unit_of_measure_row_18[] = {"9043","British link (Sears 1922)","length","9001","7.92","39.370147","Uses Sear's 1922 British yard-metre ratio as given by Bomford as 39.370147 inches per metre.  Used in East Malaysian and older New Zealand mapping.","G. Bomford \"Geodesy\" 2nd edition 1962; after J.S.Clark \"Remeasurement of the Old Length Standards\"; Empire Survey Review no. 90; 1953.","EPSG","2000-05-07","97.233  99.99","0 ",NULL};
datafile_rows_t unit_of_measure_row_19[] = {"9050","British yard (Benoit 1895 A)","length","9001","0.9143992","1","Uses Benoit's 1895 British yard-metre ratio as given by Clark as 0.9143992 metres per yard.  Used for deriving metric size of ellipsoid in Palestine.","J.S.Clark; \"Remeasurement of the Old Length Standards\"; Empire Survey Review no. 90; 1953.","EPSG","2006-03-21","97.233  99.99  2006.26","0 ",NULL};
datafile_rows_t unit_of_measure_row_20[] = {"9051","British foot (Benoit 1895 A)","length","9001","0.9143992","3","Uses Benoit's 1895 British yard-metre ratio as given by Clark as 0.9143992 metres per yard.  Used for deriving metric size of ellipsoid in Palestine.","J.S.Clark; \"Remeasurement of the Old Length Standards\"; Empire Survey Review no. 90; 1953.","EPSG","2006-03-21","97.233  99.99  2006.26","0 ",NULL};
datafile_rows_t unit_of_measure_row_21[] = {"9052","British chain (Benoit 1895 A)","length","9001","20.1167824","1","Uses Benoit's 1895 British yard-metre ratio as given by Clark as 0.9143992 metres per yard.  Used for deriving metric size of ellipsoid in Palestine.","J.S.Clark; \"Remeasurement of the Old Length Standards\"; Empire Survey Review no. 90; 1953.","EPSG","2006-03-21","97.233  99.99  2006.26","0 ",NULL};
datafile_rows_t unit_of_measure_row_22[] = {"9053","British link (Benoit 1895 A)","length","9001","0.201167824","1","Uses Benoit's 1895 British yard-metre ratio as given by Clark as 0.9143992 metres per yard.  Used for deriving metric size of ellipsoid in Palestine.","J.S.Clark; \"Remeasurement of the Old Length Standards\"; Empire Survey Review no. 90; 1953.","EPSG","2006-03-21","97.233  99.99  2006.26","0 ",NULL};
datafile_rows_t unit_of_measure_row_23[] = {"9060","British yard (Benoit 1895 B)","length","9001","36","39.370113","G. Bomford \"Geodesy\" 2nd edition 1962; after J.S.Clark \"Remeasurement of the Old Length Standards\"; Empire Survey Review no. 90; 1953.","G. Bomford \"Geodesy\" 2nd edition 1962; after J.S.Clark \"Remeasurement of the Old Length Standards\"; Empire Survey Review no. 90; 1953.","EPSG","2000-05-07","97.233  99.99","0 ",NULL};
datafile_rows_t unit_of_measure_row_24[] = {"9061","British foot (Benoit 1895 B)","length","9001","12","39.370113","Uses Benoit's 1895 British yard-metre ratio as given by Bomford as 39.370113 inches per metre.  Used in West Malaysian mapping.","G. Bomford \"Geodesy\" 2nd edition 1962; after J.S.Clark \"Remeasurement of the Old Length Standards\"; Empire Survey Review no. 90; 1953.","EPSG","2000-05-07","97.233  99.99","0 ",NULL};
datafile_rows_t unit_of_measure_row_25[] = {"9062","British chain (Benoit 1895 B)","length","9001","792","39.370113","Uses Benoit's 1895 British yard-metre ratio as given by Bomford as 39.370113 inches per metre.  Used in West Malaysian mapping.","G. Bomford \"Geodesy\" 2nd edition 1962; after J.S.Clark \"Remeasurement of the Old Length Standards\"; Empire Survey Review no. 90; 1953.","EPSG","2000-05-07","97.233  99.99","0 ",NULL};
datafile_rows_t unit_of_measure_row_26[] = {"9063","British link (Benoit 1895 B)","length","9001","7.92","39.370113","Uses Benoit's 1895 British yard-metre ratio as given by Bomford as 39.370113 inches per metre.  Used in West Malaysian mapping.","G. Bomford; \"Geodesy\"; 3rd edition 1975","EPSG","2000-05-07","97.233  99.99","0 ",NULL};
datafile_rows_t unit_of_measure_row_27[] = {"9070","British foot (1865)","length","9001","0.9144025","3","Uses Clark's estimate of 1853-1865 British foot-metre ratio of 0.9144025 metres per yard.  Used in 1962 and 1975 estimates of Indian foot.","J.S.Clark; \"Remeasurement of the Old Length Standards\"; Empire Survey Review no. 90; 1953.","EPSG","2000-05-07","97.233  99.99","0 ",NULL};
datafile_rows_t unit_of_measure_row_28[] = {"9080","Indian foot","length","9001","12","39.370142","Indian Foot = 0.99999566 British feet (A.R.Clarke 1865).  British yard (= 3 British feet) taken to be J.S.Clark's 1865 value of 0.9144025 metres.","G. Bomford; \"The Re-adjustment of the Indian Triangulation\"; Survey of India Professional Paper 28; 1939.","EPSG","2000-05-07","97.231  99.99","0 ",NULL};
datafile_rows_t unit_of_measure_row_29[] = {"9081","Indian foot (1937)","length","9001","0.30479841","1","Indian Foot = 0.99999566 British feet (A.R.Clarke 1865).  British foot taken to be 1895 Benoit value of 12/39.370113m.  Rounded to 8 decimal places as 0.30479841. Used from Bangladesh to Vietnam.  Previously used in India and Pakistan but superseded.","G. Bomford; \"The Re-adjustment of the Indian Triangulation\"; Survey of India Professional Paper 28; 1939.","EPSG","2000-05-07","97.231  99.99","0 ",NULL};
datafile_rows_t unit_of_measure_row_30[] = {"9082","Indian foot (1962)","length","9001","0.3047996","1","Indian Foot = 0.99999566 British feet (A.R.Clarke 1865).  British yard (3 feet) taken to be J.S. Clark's 1865 value of 0.9144025m. Rounded to 7 significant figures with a small error as 1 Ind ft=0.3047996m.  Used in Pakistan since metrication.","G. Bomford; \"Geodesy\"; 2nd edition 1962","EPSG","2007-01-25","97.231 99.99 2007.011","0 ",NULL};
datafile_rows_t unit_of_measure_row_31[] = {"9083","Indian foot (1975)","length","9001","0.3047995","1","Indian Foot = 0.99999566 British feet (A.R.Clarke 1865).  British yard (3 feet) taken to be J.S. Clark's 1865 value of 0.9144025m. Rounded to 7 significant figures as 1 Ind ft=0.3047995m.  Used in India since metrication.","G. Bomford; \"Geodesy\"; 3rd edition 1975","EPSG","2007-01-25","97.231 99.99 2007.011","0 ",NULL};
datafile_rows_t unit_of_measure_row_32[] = {"9084","Indian yard","length","9001","36","39.370142","Indian Foot = 0.99999566 British feet (A.R.Clarke 1865).  British yard (= 3 British feet) taken to be J.S.Clark's 1865 value of 0.9144025 metres.","G. Bomford; \"The Re-adjustment of the Indian Triangulation\"; Survey of India Professional Paper 28; 1939.","EPSG","2000-05-07","97.231  99.99","0 ",NULL};
datafile_rows_t unit_of_measure_row_33[] = {"9085","Indian yard (1937)","length","9001","0.91439523","1","Indian Foot = 0.99999566 British feet (A.R.Clarke 1865).  British foot taken to be 1895 Benoit value of 12/39.370113m.  Rounded to 8 decimal places as 0.30479841. Used from Bangladesh to Vietnam.  Previously used in India and Pakistan but superseded.","G. Bomford; \"The Re-adjustment of the Indian Triangulation\"; Survey of India Professional Paper 28; 1939.","EPSG","2000-05-07","97.231  99.99","0 ",NULL};
datafile_rows_t unit_of_measure_row_34[] = {"9086","Indian yard (1962)","length","9001","0.9143988","1","Indian Foot = 0.99999566 British feet (A.R.Clarke 1865).  British yard (3 feet) taken to be J.S. Clark's 1865 value of 0.9144025m. Rounded to 7 significant figures with a small error as 1 Ind ft=0.3047996m.  Used in Pakistan since metrication.","G. Bomford; \"Geodesy\"; 2nd edition 1962","EPSG","2007-01-25","97.231 99.99 2007.011","0 ",NULL};
datafile_rows_t unit_of_measure_row_35[] = {"9087","Indian yard (1975)","length","9001","0.9143985","1","Indian Foot = 0.99999566 British feet (A.R.Clarke 1865).  British yard (3 feet) taken to be J.S. Clark's 1865 value of 0.9144025m. Rounded to 7 significant figures as 1 Ind ft=0.3047995m.  Used in India since metrication.","G. Bomford; \"Geodesy\"; 3rd edition 1975","EPSG","2007-01-25","97.231 99.99 2007.011","0 ",NULL};
datafile_rows_t unit_of_measure_row_36[] = {"9093","Statute mile","length","9001","1609.344","1","=5280 feet","EPSG","EPSG","2000-03-07","","0 ",NULL};
datafile_rows_t unit_of_measure_row_37[] = {"9094","Gold Coast foot","length","9001","6378300","20926201","Used in Ghana and some adjacent parts of British west Africa prior to metrication, except for the metrication of projection defining parameters when British foot (Sears 1922) used.","Ordnance Survey International","EPSG","2001-01-21","2000.86","0 ",NULL};
datafile_rows_t unit_of_measure_row_38[] = {"9095","British foot (1936)","length","9001","0.3048007491","1","For the 1936 retriangulation OSGB defines the relationship of 10 feet of 1796 to the International metre through the logarithmic relationship (10^0.48401603 exactly). 1 ft = 0.3048007491m. Also used for metric conversions in Ireland.","1. \"The Retriangulation of Great Britain\", Ordnance Survey of Great Britain. 2. \"The Irish Grid - A Description of the Co-ordinate Reference System\" published by Ordnance Survey of Ireland, Dublin and Ordnance Survey of Northern Ireland, Belfast.","EPSG","2006-11-27","2002.621 2006.932","0 ",NULL};
datafile_rows_t unit_of_measure_row_39[] = {"9096","yard","length","9001","0.9144","1","=3 international feet.","OGP","OGP","2006-07-14","","0 ",NULL};
datafile_rows_t unit_of_measure_row_40[] = {"9097","chain","length","9001","20.1168","1","=22 international yards or 66 international feet.","OGP","OGP","2006-07-14","","0 ",NULL};
datafile_rows_t unit_of_measure_row_41[] = {"9098","link","length","9001","20.1168","100","=1/100 international chain.","OGP","OGP","2006-07-14","","0 ",NULL};
datafile_rows_t unit_of_measure_row_42[] = {"9099","British yard (Sears 1922 truncated)","length","9001","0.914398","1","Uses Sear's 1922 British yard-metre ratio (UoM code 9040) truncated to 6 significant figures.","Defence Geographic Centre","OGP","2006-10-23","2006.901","0 ",NULL};
datafile_rows_t unit_of_measure_row_43[] = {"9101","radian","angle","9101","1","1","SI standard unit.","ISO 1000:1992","EPSG","1995-06-02","","0 ",NULL};
datafile_rows_t unit_of_measure_row_44[] = {"9102","degree","angle","9101","3.14159265358979","180","= pi/180 radians","","EPSG","2002-11-18","96.22 2002.86","0 ",NULL};
datafile_rows_t unit_of_measure_row_45[] = {"9103","arc-minute","angle","9101","3.14159265358979","10800","1/60th degree = ((pi/180) / 60) radians","","EPSG","2002-11-18","96.22 2002.86","0 ",NULL};
datafile_rows_t unit_of_measure_row_46[] = {"9104","arc-second","angle","9101","3.14159265358979","648000","1/60th arc-minute = ((pi/180) / 3600) radians","","EPSG","2002-11-18","96.22 2002.86","0 ",NULL};
datafile_rows_t unit_of_measure_row_47[] = {"9105","grad","angle","9101","3.14159265358979","200","=pi/200 radians.","","EPSG","2002-11-18","96.22  99.05 2002.86","0 ",NULL};
datafile_rows_t unit_of_measure_row_48[] = {"9106","gon","angle","9101","3.14159265358979","200","=pi/200 radians","","EPSG","2002-11-18","96.22 2002.86","0 ",NULL};
datafile_rows_t unit_of_measure_row_49[] = {"9107","degree minute second","angle","9102","","","Degree representation. Format: signed degrees (integer) - arc-minutes (integer) - arc-seconds (real, any precision). Different symbol sets are in use as field separators, for example º ' \". Convert to degrees using algorithm.","EPSG","EPSG","2002-11-22","96.19 2002.07 2002.78","0 ",NULL};
datafile_rows_t unit_of_measure_row_50[] = {"9108","degree minute second hemisphere","angle","9102","","","Degree representation. Format: degrees (integer) - arc-minutes (integer) - arc-seconds (real) - hemisphere abbreviation (single character N S E or W). Different symbol sets are in use as field separators for example º ' \". Convert to deg using algorithm.","EPSG","EPSG","2002-11-22","96.19 2002.07 2002.78","0 ",NULL};
datafile_rows_t unit_of_measure_row_51[] = {"9109","microradian","angle","9101","1","1000000","rad * 10E-6","ISO 1000.","EPSG","1996-10-18","99.05","0 ",NULL};
datafile_rows_t unit_of_measure_row_52[] = {"9110","sexagesimal DMS","angle","9102","","","Pseudo unit format: signed degrees - period - minutes (two digits) - integer seconds (two digits) - fraction of seconds (any precision). Must include leading zero in minutes and seconds and exclude decimal point for seconds. Convert to deg using formula.","EPSG","EPSG","2002-11-22","2002.27 2002.78","0 ",NULL};
datafile_rows_t unit_of_measure_row_53[] = {"9111","sexagesimal DM","angle","9102","","","Pseudo unit. Format: sign - degrees - decimal point - integer minutes (two digits) - fraction of minutes (any precision).  Must include leading zero in integer minutes.  Must exclude decimal point for minutes.  Convert to deg using algorithm.","EPSG","EPSG","2002-11-22","2002.07 2002.78","0 ",NULL};
datafile_rows_t unit_of_measure_row_54[] = {"9112","centesimal minute","angle","9101","3.14159265358979","20000","1/100 of a grad and gon = ((pi/200) / 100) radians","http://www.geodesy.matav.hu/","EPSG","2005-09-06","98.48  99.51 2002.86 2005.46","0 ",NULL};
datafile_rows_t unit_of_measure_row_55[] = {"9113","centesimal second","angle","9101","3.14159265358979","2000000","1/100 of a centesimal minute or 1/10,000th of a grad and gon = ((pi/200) / 10000) radians","http://www.geodesy.matav.hu/","EPSG","2005-09-06","99.51 2002.86 2005.46","0 ",NULL};
datafile_rows_t unit_of_measure_row_56[] = {"9114","mil_6400","angle","9101","3.14159265358979","3200","Angle subtended by 1/6400 part of a circle.  Approximates to 1/1000th radian.  Note that other approximations (notably 1/6300 circle and 1/6000 circle) also exist.","http://www.geodesy.matav.hu/","EPSG","2005-09-06","99.51 2005.46","0 ",NULL};
datafile_rows_t unit_of_measure_row_57[] = {"9115","degree minute","angle","9102","","","Degree representation. Format: signed degrees (integer)  - arc-minutes (real, any precision). Different symbol sets are in use as field separators, for example º '. Convert to degrees using algorithm.","EPSG","EPSG","2002-11-22","2002.78","0 ",NULL};
datafile_rows_t unit_of_measure_row_58[] = {"9116","degree hemisphere","angle","9102","","","Degree representation. Format: degrees (real, any precision) - hemisphere abbreviation (single character N S E or W). Convert to degrees using algorithm.","EPSG","EPSG","2002-11-22","","0 ",NULL};
datafile_rows_t unit_of_measure_row_59[] = {"9117","hemisphere degree","angle","9102","","","Degree representation. Format: hemisphere abbreviation (single character N S E or W) - degrees (real, any precision). Convert to degrees using algorithm.","EPSG","EPSG","2002-11-22","","0 ",NULL};
datafile_rows_t unit_of_measure_row_60[] = {"9118","degree minute hemisphere","angle","9102","","","Degree representation. Format: degrees (integer) - arc-minutes (real, any precision) - hemisphere abbreviation (single character N S E or W). Different symbol sets are in use as field separators, for example º '. Convert to degrees using algorithm.","EPSG","EPSG","2002-11-22","","0 ",NULL};
datafile_rows_t unit_of_measure_row_61[] = {"9119","hemisphere degree minute","angle","9102","","","Degree representation. Format:  hemisphere abbreviation (single character N S E or W) - degrees (integer) - arc-minutes (real, any precision). Different symbol sets are in use as field separators, for example º '. Convert to degrees using algorithm.","EPSG","EPSG","2002-11-22","","0 ",NULL};
datafile_rows_t unit_of_measure_row_62[] = {"9120","hemisphere degree minute second","angle","9102","","","Degree representation. Format: hemisphere abbreviation (single character N S E or W) - degrees (integer) - arc-minutes (integer) - arc-seconds (real). Different symbol sets are in use as field separators for example º ' \". Convert to deg using algorithm.","EPSG","EPSG","2002-11-22","","0 ",NULL};
datafile_rows_t unit_of_measure_row_63[] = {"9121","sexagesimal DMS.s","angle","9102","","","Pseudo unit. Format: signed degrees - minutes (two digits) - seconds (real, any precision). Must include leading zero in minutes and seconds where value is under 10 and include decimal separator for seconds. Convert to degree using algorithm.","ISO 6709:1983.","EPSG","2002-11-22","","0 ",NULL};
datafile_rows_t unit_of_measure_row_64[] = {"9122","degree (supplier to define representation)","angle","9101","3.14159265358979","180","= pi/180 radians. The degree representation (e.g. decimal, DMSH, etc.) must be clarified by suppliers of data associated with this code.","EPSG","EPSG","2004-01-05","","0 ",NULL};
datafile_rows_t unit_of_measure_row_65[] = {"9201","unity","scale","9201","1","1","","","EPSG","1996-09-12","","0 ",NULL};
datafile_rows_t unit_of_measure_row_66[] = {"9202","parts per million","scale","9201","1","1000000","","","EPSG","1996-09-12","","0 ",NULL};
datafile_rows_t unit_of_measure_row_67[] = {"9203","coefficient","scale","9201","1","1","Used when parameters are coefficients.  They inherently take the units which depend upon the term to which the coefficient applies.","EPSG","EPSG","2004-09-14","2004.53","0 ",NULL};
datafile_rows_t unit_of_measure_row_68[] = {"9204","Bin width 330 US survey feet","length","9001","3960","39.37","","EPSG","EPSG","2000-10-19","2000.59","0 ",NULL};
datafile_rows_t unit_of_measure_row_69[] = {"9205","Bin width 165 US survey feet","length","9001","1980","39.37","","EPSG","EPSG","2000-10-19","2000.59","0 ",NULL};
datafile_rows_t unit_of_measure_row_70[] = {"9206","Bin width 82.5 US survey feet","length","9001","990","39.37","","EPSG","EPSG","2000-10-19","2000.59","0 ",NULL};
datafile_rows_t unit_of_measure_row_71[] = {"9207","Bin width 37.5 metres","length","9001","37.5","1","","EPSG","EPSG","2000-10-19","2000.59","0 ",NULL};
datafile_rows_t unit_of_measure_row_72[] = {"9208","Bin width 25 metres","length","9001","25","1","","EPSG","EPSG","2000-10-19","2000.59","0 ",NULL};
datafile_rows_t unit_of_measure_row_73[] = {"9209","Bin width 12.5 metres","length","9001","12.5","1","","EPSG","EPSG","2000-10-19","2000.59","0 ",NULL};
datafile_rows_t unit_of_measure_row_74[] = {"9210","Bin width 6.25 metres","length","9001","6.25","1","","EPSG","EPSG","2000-10-19","2000.59","0 ",NULL};
datafile_rows_t unit_of_measure_row_75[] = {"9211","Bin width 3.125 metres","length","9001","3.125","1","","EPSG","EPSG","2000-10-19","2000.59","0 ",NULL};
datafile_rows_t unit_of_measure_row_76[] = {"9300","British foot (Sears 1922 truncated)","length","9001","0.914398","3","Uses Sear's 1922 British yard-metre ratio (UoM code 9040) truncated to 6 significant figures; this truncated ratio (0.914398, UoM code 9099) then converted to other imperial units. 3 ftSe(T) = 1 ydSe(T).","Defence Geographic Centre","OGP","2006-10-23","2006.901","0 ",NULL};
datafile_rows_t unit_of_measure_row_77[] = {"9301","British chain (Sears 1922 truncated)","length","9001","20.116756","1","Uses Sear's 1922 British yard-metre ratio (UoM code 9040) truncated to 6 significant figures; this truncated ratio (0.914398, UoM code 9099) then converted to other imperial units. 1 chSe(T) = 22 ydSe(T). Used in metrication of Malaya RSO grid.","Defence Geographic Centre","OGP","2006-10-23","2006.901","0 ",NULL};
datafile_rows_t unit_of_measure_row_78[] = {"9302","British link (Sears 1922 truncated)","length","9001","20.116756","100","Uses Sear's 1922 British yard-metre ratio (UoM code 9040) truncated to 6 significant figures; this truncated ratio (0.914398, UoM code 9099) then converted to other imperial units. 100 lkSe(T) = 1 chSe(T).","Defence Geographic Centre","OGP","2006-10-23","2006.901","0 ",NULL};
datafile_rows_t *unit_of_measure_rows[] = {unit_of_measure_row_0 ,unit_of_measure_row_1 ,unit_of_measure_row_2 ,unit_of_measure_row_3 ,unit_of_measure_row_4 ,unit_of_measure_row_5 ,unit_of_measure_row_6 ,unit_of_measure_row_7 ,unit_of_measure_row_8 ,unit_of_measure_row_9 ,unit_of_measure_row_10 ,unit_of_measure_row_11 ,unit_of_measure_row_12 ,unit_of_measure_row_13 ,unit_of_measure_row_14 ,unit_of_measure_row_15 ,unit_of_measure_row_16 ,unit_of_measure_row_17 ,unit_of_measure_row_18 ,unit_of_measure_row_19 ,unit_of_measure_row_20 ,unit_of_measure_row_21 ,unit_of_measure_row_22 ,unit_of_measure_row_23 ,unit_of_measure_row_24 ,unit_of_measure_row_25 ,unit_of_measure_row_26 ,unit_of_measure_row_27 ,unit_of_measure_row_28 ,unit_of_measure_row_29 ,unit_of_measure_row_30 ,unit_of_measure_row_31 ,unit_of_measure_row_32 ,unit_of_measure_row_33 ,unit_of_measure_row_34 ,unit_of_measure_row_35 ,unit_of_measure_row_36 ,unit_of_measure_row_37 ,unit_of_measure_row_38 ,unit_of_measure_row_39 ,unit_of_measure_row_40 ,unit_of_measure_row_41 ,unit_of_measure_row_42 ,unit_of_measure_row_43 ,unit_of_measure_row_44 ,unit_of_measure_row_45 ,unit_of_measure_row_46 ,unit_of_measure_row_47 ,unit_of_measure_row_48 ,unit_of_measure_row_49 ,unit_of_measure_row_50 ,unit_of_measure_row_51 ,unit_of_measure_row_52 ,unit_of_measure_row_53 ,unit_of_measure_row_54 ,unit_of_measure_row_55 ,unit_of_measure_row_56 ,unit_of_measure_row_57 ,unit_of_measure_row_58 ,unit_of_measure_row_59 ,unit_of_measure_row_60 ,unit_of_measure_row_61 ,unit_of_measure_row_62 ,unit_of_measure_row_63 ,unit_of_measure_row_64 ,unit_of_measure_row_65 ,unit_of_measure_row_66 ,unit_of_measure_row_67 ,unit_of_measure_row_68 ,unit_of_measure_row_69 ,unit_of_measure_row_70 ,unit_of_measure_row_71 ,unit_of_measure_row_72 ,unit_of_measure_row_73 ,unit_of_measure_row_74 ,unit_of_measure_row_75 ,unit_of_measure_row_76 ,unit_of_measure_row_77 ,unit_of_measure_row_78,NULL};
